<?php
ob_start('ob_gzhandler');
include('../../api/config.php');

$Pos = json_decode(file_get_contents('php://input'));

$query = "SELECT *,
    (CASE 
        WHEN height IS NOT NULL THEN height 
        WHEN area IS NOT NULL THEN area 
        WHEN Code6 IS NOT NULL THEN Code6 
        WHEN basements IS NOT NULL THEN basements 
        WHEN numberofbuildings IS NOT NULL THEN numberofbuildings 
    END) AS max_value
    FROM QC
    WHERE height IS NOT NULL
    ORDER BY Name, max_value DESC";

$result = $mysqli->query($query);

$return = [];
$personRecords = []; // To keep track of records for each person
if ($result) {
    while ($row = $result->fetch_assoc()) {
        $person = $row['Name'];
        if (!isset($personRecords[$person])) {
            $personRecords[$person] = [];
        }
        
        $personRecords[$person][] = $row;
    }
    
    foreach ($personRecords as $person => $records) {
        $limit = floor(count($records) * 0.1); // Round down for 10% limit
        if ($limit < 1) {
            $limit = 1; // Ensure $limit is at least 1
        }
        $selectedRecords = [];
        
        $types = ['area', 'height', 'basements', 'constructiontype', 'structuretype', 'numberofbuildings'];
        
        // Select first six projects based on specified criteria
        foreach ($types as $type) {
            $typeRecords = array_filter($records, function ($record) use ($type) {
                return is_numeric($record[$type]); // Check if value is numeric
            });
            
            usort($typeRecords, function ($a, $b) use ($type) {
                return $b[$type] - $a[$type];
            });
            
            if (!empty($typeRecords)) {
                $selectedRecords[] = array_shift($typeRecords);
            }
        }
        
        // Randomly select remaining projects
        $remainingRecords = array_slice($records, 6); // Exclude the first six projects
        shuffle($remainingRecords);
        $selectedRecords = array_merge($selectedRecords, $remainingRecords);
        
        // Ensure we don't exceed the calculated limit
        if (count($selectedRecords) > $limit) {
            $selectedRecords = array_slice($selectedRecords, 0, $limit);
        }
        
        // Process and add selected records to $return
        foreach ($selectedRecords as $record) {
            $return[] = $record;
        }
    }
    
    $return["error"] = false;
}

header('Content-Type: application/json');
echo json_encode($return);
?>
